diff lisp/ffap.el @ 22250:a77d473867b8

*** empty log message ***
author Dan Nicolaescu <done@ece.arizona.edu>
date Tue, 26 May 1998 09:23:23 +0000
parents daca88de8a78
children 95a8d00b0c5c
line wrap: on
line diff
--- a/lisp/ffap.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/ffap.el	Tue May 26 09:23:23 1998 +0000
@@ -4,7 +4,7 @@
 ;;
 ;; Author: Michelangelo Grigni <mic@mathcs.emory.edu>
 ;; Created: 29 Mar 1993
 ;; Keywords: files, hypermedia, matching, mouse
 ;; X-URL: ftp://ftp.mathcs.emory.edu/pub/mic/emacs/
 
 ;; This file is part of GNU Emacs.
@@ -105,7 +105,8 @@
 (defgroup ffap nil
   "Find file or URL at point."
   :link '(url-link :tag "URL" "ftp://ftp.mathcs.emory.edu/pub/mic/emacs/")
-  :group 'matching)
+  :group 'matching
+  :group 'convenience)
 
 ;; The code is organized in pages, separated by formfeed characters.
 ;; See the next two pages for standard customization ideas.
@@ -4,7 +4,7 @@
 ;; Author: Michelangelo Grigni <mic@mathcs.emory.edu>
 ;; Created: 29 Mar 1993
-;; Keywords: files, hypermedia, matching, mouse
+;; Keywords: files, hypermedia, matching, mouse, convenience
 ;; X-URL: ftp://ftp.mathcs.emory.edu/pub/mic/emacs/
 